cli

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2025 License: AGPL-3.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute runs the CLI

Types

type ComparisonResult added in v0.1.1

type ComparisonResult struct {
	ConfigVars       []string // Variables defined in config
	DeploymentVars   []string // Variables defined in deployment
	InConfigOnly     []string // Variables in config but not in deployment
	InDeploymentOnly []string // Variables in deployment but not in config
	Matching         []string // Variables in both config and deployment
}

ComparisonResult holds the result of comparing config vs deployment

type ConfigMapKeyRef added in v0.1.1

type ConfigMapKeyRef struct {
	Name string `yaml:"name"`
	Key  string `yaml:"key"`
}

ConfigMapKeyRef represents a reference to a config map key

type Container added in v0.1.1

type Container struct {
	Name string   `yaml:"name"`
	Env  []EnvVar `yaml:"env,omitempty"`
}

Container represents a container in a K8s deployment

type EnvVar added in v0.1.1

type EnvVar struct {
	Name      string             `yaml:"name"`
	Value     string             `yaml:"value,omitempty"`
	ValueFrom *EnvVarValueSource `yaml:"valueFrom,omitempty"`
}

EnvVar represents an environment variable in a K8s container

type EnvVarValueSource added in v0.1.1

type EnvVarValueSource struct {
	SecretKeyRef    *SecretKeyRef    `yaml:"secretKeyRef,omitempty"`
	ConfigMapKeyRef *ConfigMapKeyRef `yaml:"configMapKeyRef,omitempty"`
}

EnvVarValueSource represents the source of an environment variable value

type KubernetesDeployment added in v0.1.1

type KubernetesDeployment struct {
	APIVersion string `yaml:"apiVersion"`
	Kind       string `yaml:"kind"`
	Spec       struct {
		Template struct {
			Spec struct {
				Containers []Container `yaml:"containers"`
			} `yaml:"spec"`
		} `yaml:"template"`
	} `yaml:"spec"`
}

KubernetesDeployment represents the structure we care about in a K8s deployment

type SecretKeyRef added in v0.1.1

type SecretKeyRef struct {
	Name string `yaml:"name"`
	Key  string `yaml:"key"`
}

SecretKeyRef represents a reference to a secret key

Jump to