Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ComparisonResult ¶ added in v0.1.1
type ComparisonResult struct {
ConfigVars []string // Variables defined in config
DeploymentVars []string // Variables defined in deployment
InConfigOnly []string // Variables in config but not in deployment
InDeploymentOnly []string // Variables in deployment but not in config
Matching []string // Variables in both config and deployment
}
ComparisonResult holds the result of comparing config vs deployment
type ConfigMapKeyRef ¶ added in v0.1.1
ConfigMapKeyRef represents a reference to a config map key
type EnvVar ¶ added in v0.1.1
type EnvVar struct {
Name string `yaml:"name"`
Value string `yaml:"value,omitempty"`
ValueFrom *EnvVarValueSource `yaml:"valueFrom,omitempty"`
}
EnvVar represents an environment variable in a K8s container
type EnvVarValueSource ¶ added in v0.1.1
type EnvVarValueSource struct {
SecretKeyRef *SecretKeyRef `yaml:"secretKeyRef,omitempty"`
ConfigMapKeyRef *ConfigMapKeyRef `yaml:"configMapKeyRef,omitempty"`
}
EnvVarValueSource represents the source of an environment variable value
type KubernetesDeployment ¶ added in v0.1.1
type KubernetesDeployment struct {
APIVersion string `yaml:"apiVersion"`
Kind string `yaml:"kind"`
Spec struct {
Template struct {
Spec struct {
Containers []Container `yaml:"containers"`
} `yaml:"spec"`
} `yaml:"template"`
} `yaml:"spec"`
}
KubernetesDeployment represents the structure we care about in a K8s deployment
type SecretKeyRef ¶ added in v0.1.1
SecretKeyRef represents a reference to a secret key
Click to show internal directories.
Click to hide internal directories.